@@ -3,6 +3,7 @@ Fixtures for pytest.
 """
 
 import locale
+from typing import Iterator
 
 import hypothesis
 import pytest
@@ -12,12 +13,11 @@ import pytest
 # For some reason it thinks that the text/binary generation is too
 # slow then causes the tests to fail.
 hypothesis.settings.register_profile(
-    "slow-tests",
-    suppress_health_check=[hypothesis.HealthCheck.too_slow],
+    "slow-tests", suppress_health_check=[hypothesis.HealthCheck.too_slow]
 )
 
 
-def load_locale(x):
+def load_locale(x: str) -> None:
     """Convenience to load a locale, trying ISO8859-1 first."""
     try:
         locale.setlocale(locale.LC_ALL, str("{}.ISO8859-1".format(x)))
@@ -26,15 +26,16 @@ def load_locale(x):
 
 
 @pytest.fixture()
-def with_locale_en_us():
+def with_locale_en_us() -> Iterator[None]:
     """Convenience to load the en_US locale - reset when complete."""
     orig = locale.getlocale()
-    yield load_locale("en_US")
+    load_locale("en_US")
+    yield
     locale.setlocale(locale.LC_ALL, orig)
 
 
 @pytest.fixture()
-def with_locale_de_de():
+def with_locale_de_de() -> Iterator[None]:
     """
     Convenience to load the de_DE locale - reset when complete - skip if missing.
     """
